/**
 * Ant Design Pro v4 use `@ant-design/pro-layout` to handle Layout.
 * You can view component api by:
 * https://github.com/ant-design/ant-design-pro-layout
 */
import ProLayout, {
    MenuDataItem,
    BasicLayoutProps as ProLayoutProps,
    Settings,
    DefaultFooter,
    SettingDrawer,
} from '@ant-design/pro-layout';
import React, { useEffect } from 'react';
import { Link, useIntl, connect, Dispatch, MicroApp } from 'umi';
import { GithubOutlined } from '@ant-design/icons';
import { Result, Button } from 'antd';
import Authorized from '@/utils/Authorized';
import RightContent from '@/components/GlobalHeader/RightContent';
import { ConnectState } from '@/models/connect';
import { getAuthorityFromRouter } from '@/utils/utils';
import logo from '../assets/kaipingLogo.svg';
import { JsonHubProtocol, HttpTransportType, HubConnectionBuilder, LogLevel } from "@aspnet/signalr";
// import { createConnectionContext } from "@hwdtech/react-signalr";
// import component from '@/locales/zh-TW/component';

const noMatch = (
    <Result
        status={403}
        title="403"
        subTitle="Sorry, you are not authorized to access this page."
        extra={
            <Button type="primary">
                <Link to="/user/login">Go Login</Link>
            </Button>
        }
    />
);
export interface BasicLayoutProps extends ProLayoutProps {
    breadcrumbNameMap: {
        [path: string]: MenuDataItem;
    };
    route: ProLayoutProps['route'] & {
        authority: string[];
    };
    settings: Settings;
    dispatch: Dispatch;
}
export type BasicLayoutContext = { [K in 'location']: BasicLayoutProps[K] } & {
    breadcrumbNameMap: {
        [path: string]: MenuDataItem;
    };
};
/**
 * use Authorized check all menu item
 */

const menuDataRender = (menuList: MenuDataItem[]): MenuDataItem[] =>
    menuList.map((item) => {
        const localItem = { ...item, children: item.children ? menuDataRender(item.children) : [] };
        return Authorized.check(item.authority, localItem, null) as MenuDataItem;
    });

const footName = localStorage.getItem('footName')

const defaultFooterDom = (
    <div style={{ width: '100%', textAlign: 'center', lineHeight: '3rem', color: '#999' }}
        dangerouslySetInnerHTML={{ __html: footName }}
    >

    </div>
    // <DefaultFooter
    //   copyright={footName === null ? '东师理想股份有限公司': footName}
    //   links={[]}
    // />
);

const BasicLayout: React.FC<BasicLayoutProps> = (props) => {
    const {
        dispatch,
        children,
        settings,
        location = {
            pathname: '/',
        },
    } = props;

    /**
     * constructor
     */



    // useEffect(() => {
    //   if (dispatch) {
    //     dispatch({
    //       type: 'user/fetchCurrent',
    //     });
    //   }
    // }, []);
    /**
     * init variables
     */

    const handleMenuCollapse = (payload: boolean): void => {
        if (dispatch) {
            dispatch({
                type: 'global/changeLayoutCollapsed',
                payload,
            });
        }
    }; // get children authority

    const authorized = getAuthorityFromRouter(props.route.routes, location.pathname || '/') || {
        authority: undefined,
    };
    const { formatMessage } = useIntl();

    settings.layout = 'topmenu'
    return (
        <>
            {/* <Consumer>
      {({ connection, connectionError }) => {
        
        if (connection) {
          
        }
        if (connectionError) {
          debugger
        }

      }}
      </Consumer> */}
            <ProLayout
                // logo={logo}
                logo={(window.location.protocol + "//" + window.location.host + localStorage.getItem('logo'))}
                formatMessage={formatMessage}
                menuHeaderRender={(logoDom, titleDom) => (
                    <Link to="/">
                        {logoDom}
                        {titleDom}
                    </Link>
                )}
                onCollapse={handleMenuCollapse}
                menuItemRender={(menuItemProps, defaultDom) => {
                    if (menuItemProps.isUrl || menuItemProps.children || !menuItemProps.path) {
                        return defaultDom;
                    }

                    return <Link to={menuItemProps.path}>{defaultDom}</Link>;
                }}
                breadcrumbRender={(routers = []) => [
                    {
                        path: '/',
                        breadcrumbName: formatMessage({
                            id: 'menu.home',
                        }),
                    },
                    ...routers,
                ]}
                itemRender={(route, params, routes, paths) => {
                    const first = routes.indexOf(route) === 0;
                    return first ? (
                        <Link to={paths.join('/')}>{route.breadcrumbName}</Link>
                    ) : (
                            <span>{route.breadcrumbName}</span>
                        );
                }}
                footerRender={() => defaultFooterDom}
                menuDataRender={menuDataRender}
                rightContentRender={() => <RightContent />}
                {...props}

                {...settings}
            >
                {/* <Authorized authority={authorized!.authority} noMatch={noMatch}>
          {children}
        </Authorized> */}
                {/*<MicroApp name="sso" />*/}
            </ProLayout>
            <SettingDrawer
                settings={settings}
                onSettingChange={(config) =>
                    dispatch({
                        type: 'settings/changeSetting',
                        payload: config,
                    })
                }
            />
        </>
    );
};

export default connect(({ global, settings }: ConnectState) => ({
    collapsed: global.collapsed,
    settings,
}))(BasicLayout);
