import { Effect, Reducer } from 'umi';

import { AnalysisData } from './data.d';
import { getNodes, getProductsInNode, getProductsInfo } from './service';
import { timestampToTimeDh, timestampToTimeYMD } from '@/utils/utils';

export interface ModelType {
  namespace: string;
  state: AnalysisData;
  effects: {
    getNodes: Effect;
    getProductsInNode: Effect;
    getProductsInfo: Effect;
  };
  reducers: {
    saveNode: Reducer;
    saveProducts: Reducer;
    tempProductsInNode: Reducer;
    clear: Reducer;
  };
}

const initState = {
  nodeList: [],
  tempProductList: []
};

const Model: ModelType = {
  namespace: 'HumidityStatistics',

  state: initState,

  effects: {
    // 获取节点
    *getNodes({ payload, callback }, { call, put }) {

      const response = yield call(getNodes, payload);
      if (callback) callback(response);
    },
    // 根据节点获取节点内数据
    *getProductsInNode({ payload, callback }, { call, put }) {
      const response = yield call(getProductsInNode, payload);
      console.log(response, 'response 111')
      let tempList: any = []
      if (payload.type == "tempProductsInNode") {

        response.devices.map((d: any) => {

          if (d.product.number === "fbee:0302:01") {
            tempList.push(d)
          }
        })
      }

      if (callback) callback(tempList);
    },
    // 获取设备数据
    *getProductsInfo({ payload, callback }, { call, put }) {
      // 获取数据
      const response = yield call(getProductsInfo, payload);
      // 处理想要的内容
      const resCatch = response.results[0].series ? response.results[0].series[0].values : []
      const reData: { month: string; city: string; temperature: any; }[] = []
      console.log(response, 'hum hum')
      resCatch.map((val) => {
        console.log(payload, 'payload')
        let vTime = ""
        if (payload.time == "1d") {
          vTime = timestampToTimeDh(Date.parse(val[0]).toString().substr(0, 10), 'Y+M+D+h+m+s').substr(6, 5)
        } else {
          vTime = timestampToTimeYMD(Date.parse(val[0]).toString().substr(0, 10), 'Y+M+D+h+m+s').substr(6, 10)
        }
        // const vTime = timestampToTime(toString(Date.parse(val[0])).substr(0,10))
        const vMax = val[1]
        const vMean = val[2]
        const vMin = val[3]
        reData.push({
          day: vTime, sales: Number(vMean.toFixed(2))
        })


        // console.log(vTime,'val')
        // console.log(vTime,'val')
      })

      console.log(reData, 'reData')
      if (callback) callback(reData);
    },

  },
  reducers: {
    saveNode(state, payload) {
      return {
        ...state,
        nodeList: payload
      };

    },
    tempProductsInNode(state, payload) {
      console.log(payload, 'payload')

      const productList = payload.payload.ProductsList


      return {
        ...state,
        tempProductList: tempList
      };

    },
    saveProducts(state, payload) {
      return {
        ...state,

      };
    },
    clear() {
      return initState;
    },
  },
};

export default Model;
