import { Card, Select, Row, Col, Radio } from 'antd';

import { Link } from 'umi';
import React, { useState, useEffect } from 'react';
const { Option } = Select;
import Curved from '../Charts/Curved';
import { connect } from 'dva';
import { ModelType } from './model';


const IlluminationStatistics = (props: any) => {
  const [nodeList, setNodeList] = useState([])
  const [nowNode, setNowNode] = useState([])
  const [productList, setProductList] = useState([])
  const [nowProducts, setNowProducts] = useState("")
  const [nowTime, setNowTime] = useState("1d")

  const [proList, setProList] = useState([])


  useEffect(() => {
    const { dispatch } = props;

    dispatch({
      type: 'IlluminationStatistics/getNodes',
      payload: {
        schoolId: props.schoolId
      },
      callback: (response: any) => {
        setNodeList(response)
        setNowNode(response[0].number)
        getProductsInNode(response[0].number)
      }
    })
  }, []);

  //根据节点id获取节点下的设备
  const getProductsInNode = (nodeNumber: string) => {
    const { dispatch } = props;
    dispatch({
      type: 'IlluminationStatistics/getProductsInNode',
      payload: {
        number: nodeNumber,
        // type: "tempProductsInNode"
      },
      callback: (res: any) => {
        console.log(res, '111111111111')
        setProductList(res)       //设置设备数据
        if (res.length > 0) {
          setNowProducts(res[0].number)   //设计当前设备为第一个
          getProductsInfo(res[0].number, nowTime)   //获取当前设备数据信息
        } else {
          setNowProducts("")
          setProList([])
        }
        // setNowProducts(res[0].number)   //设计当前设备为第一个
        // getProductsInfo(res[0].number, nowTime)   //获取当前设备数据信息
      }
    })
  }

  // 获取图表数据
  const getProductsInfo = (number: string, time: string) => {
    const { dispatch } = props;
    dispatch({
      type: 'IlluminationStatistics/getProductsInfo',
      payload: {
        productKey: "Light",
        number: number,
        time: time
      },
      callback: (response: { month: string; city: string; temperature: any; }[]) => {
        // console.log(response,'123')
        setProList(response)
      }
    })
  }

  const nodeChange = (e: any) => {
    setNowNode(e)
    getProductsInNode(e)
  }


  const productChange = (e: any) => {
    setNowProducts(e)
    getProductsInfo(e, nowTime)
    // console.log(e,'target')
  }


  // const nodeList = props.IlluminationStatistics.nodeList.payload
  // const tempList: { number: number } = props.IlluminationStatistics.tempProductList

  const optionsWithDisabled = [
    { label: '24小时', value: '1d' },
    { label: '近7天', value: '7d' },
    { label: '近30天', value: '30d' },
  ];

  // 修改时间
  const nowTimeonChange = (e: any) => {

    getProductsInfo(nowProducts, e.target.value)
    setNowTime(e.target.value)

  };
  // console.log(nowNode, 'node nowNode')
  // console.log(productList, 'productList')
  // console.log(props, 'this.props')
  return (
    <Card bordered={false}
      title="光强统计"
      extra={
        <div style={{ minWidth: 300 }}>
          <Select
            style={{ width: "150px", marginRight: 10 }}
            defaultValue={nowNode}
            value={nowNode}
            onChange={nodeChange}
            virtual={false}
          >
            {nodeList?.map(province => (
              <Option key={province.number} value={province.number}>{province.name}</Option>
            ))}

          </Select>
          <Select
            defaultValue={nowProducts}
            value={nowProducts}
            style={{ width: "180px" }}
            virtual={false}
            onChange={productChange}
          >
            {productList?.map(temp => (
              <Option key={temp.number} value={temp.number} title={temp.displayName}>{temp.displayName}</Option>
            ))}
          </Select>
        </div>
      }>

      <Radio.Group
        options={optionsWithDisabled}
        onChange={nowTimeonChange}
        value={nowTime}

        optionType="button"
        buttonStyle="solid"
      />
      <Curved proList={proList} type={'lux'} />
    </Card>
  );
}

export default connect(
  ({
    IlluminationStatistics,
    loading,
  }: {
    IlluminationStatistics: ModelType;
    loading: {
      models: { [key: string]: boolean };
    };
  }) => ({
    IlluminationStatistics,
    loading: loading.models.IlluminationStatistics,
  }),
)(IlluminationStatistics);


// export default IlluminationStatistics;
