import { EllipsisOutlined } from '@ant-design/icons';
import { Col, Dropdown, Menu, Row } from 'antd';
import React, { Component, Suspense } from 'react';
import { GridContent } from '@ant-design/pro-layout';
import { RadioChangeEvent } from 'antd/es/radio';
import { RangePickerProps } from 'antd/es/date-picker/generatePicker';
import moment from 'moment';
import { connect, Dispatch } from 'umi';

import PageLoading from './components/PageLoading';
import { getTimeDistance } from './utils/utils';
import { AnalysisData } from './data';
import styles from './style.less';
import request from '@/utils/request';

const IntroduceRow = React.lazy(() => import('./components/IntroduceRow'));
const SalesCard = React.lazy(() => import('./components/SalesCard'));
const TopSearch = React.lazy(() => import('./components/TopSearch'));
const ProportionSales = React.lazy(() => import('./components/ProportionSales'));
const MainPropTion = React.lazy(() => import('./mainComponents/MainPropTion'));
const EquPropTion = React.lazy(() => import('./mainComponents/EquPropTion'));
const SchoolEqus = React.lazy(() => import('./mainComponents/SchoolEqus'));
const StatePropTion = React.lazy(() => import('./mainComponents/StatePropTion'));
const WarningPropTion = React.lazy(() => import('./mainComponents/WarningPropTion'));
const OfflineData = React.lazy(() => import('./components/OfflineData'));
const EquipmentOnline = React.lazy(() => import('./components/EquipmentOnline'));
const EnvironmentalMonitoring = React.lazy(() => import('./components/EnvironmentalMonitoring'));
// 温度统计
const TemperatureStatistics = React.lazy(() => import('./components/TemperatureStatistics/index'));
const HumidityStatistics = React.lazy(() => import('./components/HumidityStatistics/index'));
const IlluminationStatistics = React.lazy(() => import('./components/IlluminationStatistics/index'));
const PowerConsumptionStatistics = React.lazy(() =>
  import('./components/PowerConsumptionStatistics/index'),
);
// import  EquipmentOnline  from './components/EquipmentOnline';
// import  Stacked  from './components/Charts/Stacked';

type RangePickerValue = RangePickerProps<moment.Moment>['value'];

interface MainProps {
  dashboardAndmain: AnalysisData;
  dispatch: Dispatch<any>;
  loading: boolean;
}

interface MainState {
  salesType: 'all' | 'online' | 'stores';
  currentTabKey: string;
  rangePickerValue: RangePickerValue;
  schoolList: any;
}

class MainIndex extends Component<MainProps, MainState> {
  state: MainState = {
    salesType: 'all',
    currentTabKey: '',
    rangePickerValue: getTimeDistance('year'),
    schoolList: [],
  };

  reqRef: number = 0;

  timeoutId: number = 0;

  getAllList = (_this: any) => {

    request.get(`/IoTCenter/admin/Organ/Index?pageIndex=1&pageSize=20&`, {
      method: 'GET',
      headers: {
        'Authorization': 'Bearer ' + localStorage.getItem('accessToken')
      },
    }).then(function (response) {

      _this.setState({ schoolList: response.model.list })
    }).catch(function (error) {

    });


  }

  componentDidMount() {
    const { dispatch } = this.props;
    this.reqRef = requestAnimationFrame(() => {
      dispatch({
        type: 'dashboardAndmain/getProducts',
      });
    });
    dispatch({
      type: 'dashboardAndmain/getNodes',
    });
    let _this = this
    this.getAllList(_this)

  }

  componentWillUnmount() {
    const { dispatch } = this.props;
    dispatch({
      type: 'dashboardAndmain/clear',
    });
    cancelAnimationFrame(this.reqRef);
    clearTimeout(this.timeoutId);
  }

  handleChangeSalesType = (e: RadioChangeEvent) => {
    this.setState({
      salesType: e.target.value,
    });
  };

  handleTabChange = (key: string) => {
    this.setState({
      currentTabKey: key,
    });
  };

  handleRangePickerChange = (rangePickerValue: RangePickerValue) => {
    const { dispatch } = this.props;
    this.setState({
      rangePickerValue,
    });

    dispatch({
      type: 'dashboardAndmain/fetchSalesData',
    });
  };

  selectDate = (type: 'today' | 'week' | 'month' | 'year') => {
    const { dispatch } = this.props;
    this.setState({
      rangePickerValue: getTimeDistance(type),
    });

    dispatch({
      type: 'dashboardAndmain/fetchSalesData',
    });
  };

  isActive = (type: 'today' | 'week' | 'month' | 'year') => {
    const { rangePickerValue } = this.state;
    if (!rangePickerValue) {
      return '';
    }
    const value = getTimeDistance(type);
    if (!value) {
      return '';
    }
    if (!rangePickerValue[0] || !rangePickerValue[1]) {
      return '';
    }
    if (
      rangePickerValue[0].isSame(value[0] as moment.Moment, 'day') &&
      rangePickerValue[1].isSame(value[1] as moment.Moment, 'day')
    ) {
      return styles.currentDate;
    }
    return '';
  };

  render() {
    const { rangePickerValue, salesType, currentTabKey } = this.state;
    const { dashboardAndmain, loading } = this.props;
    const {
      visitData,
      visitData2,
      salesData,
      searchData,
      offlineData,
      offlineChartData,
      salesTypeData,
      salesTypeDataOnline,
      salesTypeDataOffline,

    } = dashboardAndmain;
    let salesPieData;
    if (salesType === 'all') {
      salesPieData = salesTypeData;
    } else {
      salesPieData = salesType === 'online' ? salesTypeDataOnline : salesTypeDataOffline;
    }
    const menu = (
      <Menu>
        <Menu.Item>操作一</Menu.Item>
        <Menu.Item>操作二</Menu.Item>
      </Menu>
    );

    const dropdownGroup = (
      <span className={styles.iconGroup}>
        <Dropdown overlay={menu} placement="bottomRight">
          <EllipsisOutlined />
        </Dropdown>
      </span>
    );

    const { equNum, equItem, equState, quaOnlineNum, quaOfflineNum, classNums,
      tempMin, tempAver, tempMax,
      humMin, humAver, humMax, tempNew, humNew, humUnit, tempUnit, messages, } = this.props.dashboardAndmain
    console.log(equState, 'equState')
    const equNums = [
      {
        x: '在线',
        y: quaOnlineNum
      },
      {
        x: '离线',
        y: quaOfflineNum
      },
    ]
    // console.log(this.props, 'this.props')
    // const activeKey = currentTabKey || (offlineData[0] && offlineData[0].name);
    return (
      <GridContent>
        <Row gutter={[16, 16]}>
          <Col xl={16} lg={24} md={24} sm={24} xs={24}>
            <Suspense fallback={<PageLoading />}>
              {/* 学校设备状态 */}
              <SchoolEqus schoolList={this.state.schoolList} equNum={equNum} quaOnlineNum={quaOnlineNum} quaOfflineNum={quaOfflineNum}
                classNums={classNums}
              />
            </Suspense>
          </Col>
          <Col xl={8} lg={24} md={24} sm={24} xs={24}>
            <Row gutter={[16, 16]}>
              <Col xl={24} lg={24} md={24} sm={24} xs={24}>
                <Suspense fallback={<PageLoading />}>
                  {/* 设备数量 */}
                  {/* <IntroduceRow loading={loading} equNum={equNum} quaOnlineNum={quaOnlineNum} quaOfflineNum={quaOfflineNum} /> */}
                  <EquPropTion
                    equNums={equNums}
                    loading={loading}
                  />
                </Suspense>
              </Col>

            </Row>
            <Row gutter={[16, 16]}>
              <Col xl={24} lg={24} md={24} sm={24} xs={24}>
                {/* 设备类型 */}
                <Suspense fallback={null}>
                  <MainPropTion
                    equItem={equItem}
                    loading={loading}
                  />
                </Suspense>
              </Col>
            </Row>
          </Col>
        </Row>
        <Row gutter={[16, 16]}>
          <Col xl={16} lg={24} md={24} sm={24} xs={24}>
            <Suspense fallback={<PageLoading />}>
              {/* 数据采集量 */}
              <StatePropTion props={this.props} />
            </Suspense>
          </Col>
          <Col xl={8} lg={24} md={24} sm={24} xs={24}>
            <Suspense fallback={<PageLoading />}>
              {/* 警告信息 */}
              <WarningPropTion messages={messages} />
            </Suspense>
          </Col>
        </Row>
      </GridContent>
    );
  }
}

export default connect(
  ({
    dashboardAndmain,
    loading,
  }: {
    dashboardAndmain: any;
    loading: {
      effects: { [key: string]: boolean };
    };
  }) => ({
    dashboardAndmain,
    loading: loading.effects['dashboardAndmain/fetch'],
  }),
)(MainIndex);
