import { Subscription, Reducer, Effect } from 'umi';
import emitter from '@/utils/events';
import { AnalysisData } from './data.d';
import { fakeChartData, getProductList, getProduct, getSchoolList, getNodes, getDataVolume, GetSummary } from './service';
import { timestampToTimeDh, timestampToTimeYMD } from '@/utils/utils';
import { number } from 'prop-types';

export interface ModelType {
  namespace: string;
  state: AnalysisData;
  effects: {
    fetch: Effect;
    fetchSalesData: Effect;
    getProducts: Effect;
    getProductsAll: Effect;
    getSchoolList: Effect;
    getNodes: Effect;
    getDataVolume: Effect;
    GetSummary: Effect;
  };
  reducers: {
    save: Reducer<AnalysisData>;
    updateMessages:Reducer;
    saveProducts: Reducer;
    clear: Reducer;
  };
  subscriptions: { setup: Subscription };
}

const initState = {
  equNum: "",
  equItmeNum: {},
  equState: "",
  quaOnlineNum: "",
  quaOfflineNum: "",
  tempMin: "",
  tempAver: "",
  tempMax: "",
  humMin: "",
  humAver: "",
  humMax: "",
  tempNew: "",
  humNew: "",
  humUnit: "",
  tempUnit: ""
};

const Model: ModelType = {
  namespace: 'dashboardAndmain',
  state: initState,

  effects: {
    *fetch(_, { call, put }) {
      const response = yield call(fakeChartData);
      yield put({
        type: 'save',
        payload: response,
      });
    },
    *fetchSalesData(_, { call, put }) {
      const response = yield call(fakeChartData);
      yield put({
        type: 'save',
        payload: {
          salesData: response.salesData,
        },
      });
    },
    //获取教室列表
    *getNodes({ payload, callback }, { call, put, all }) {
      const response = yield call(getNodes, payload);
      yield put({
        type: 'save',
        payload: {
          classNums: response.length,
        },
      });
    },
    //获取产品列表（通过Rest API）
    *getProducts({ payload, callback }, { call, put, all }) {
      console.log(payload, '888888888888')
      const response = yield call(getProductList, payload);

      let Result: Array<Function> = [];
      response.forEach(function (currentValue) {

        Result.push(call(getProduct, currentValue.number, payload))
      })
      const ress = yield all([Result])
      yield put({
        type: 'saveProducts',
        payload: {
          productList: response,
          // result1:result1,
          product: ress[0]
        }

      })
      if (callback) callback(response);
    },


    // 获取产品状态
    *GetSummary({ payload, callback }, { call, put, all }) {

      const response = yield call(GetSummary, payload)

      if (callback) callback(response)
    },


    //获取学校列表（通过Rest API）
    *getSchoolList({ payload, callback }, { call, put, all }) {
      const response = yield call(getSchoolList, payload);
      if (callback) callback(response);
    },
    //获取产品列表（通过Rest API）
    *getProductsAll({ payload, callback }, { call, put, all }) {

      const [result1, result2, result3, result4, result5] = yield all([
        call(getProductList, {}),
        call(getProduct, "fbee:gateway"),
        call(getProduct, "fbee:0002:01"),
        call(getProduct, "fbee:0002:03"),
        call(getProduct, "fbee:0106:01"),
        call(getProduct, "serialport")
      ])
    },
    //获取数据采集量
    *getDataVolume({ payload, callback }, { call, put, all }) {
      const response = yield call(getDataVolume, payload);


      let record = response.results[0].series[0].values
      console.log(payload, '11111133')
      let re: never[] = []
      console.log(payload.time, 'time')


      record.map((res, index) => {
        let e = {}
        // e.month = timestampToTimeYMD(Date.parse(res[0]).toString().substr(0, 10))
        payload.time == "1d" ? e.month = timestampToTimeDh(Date.parse(res[0]).toString().substr(0, 10)) : e.month = timestampToTimeYMD(Date.parse(res[0]).toString().substr(0, 10));
        e.temperature = res[1]
        e.city = '数据量'
        re.push(e)
      })

      console.log(re, '111111334')





      if (callback) callback(re);
    },
  },

  reducers: {
    save(state, { payload }) {
      return {
        ...state,
        ...payload,
      };
    },
    updateMessages(state, {payload}) {
      const {model} = payload;
      // 当前消息
      let msg = {
        name: model.name,
        title: `${model.device.displayName} ${model.name || ''} ${model.description || ''} ${model.value || ''}${model.unit || ''}`,
        time: timestampToTimeDh(model.timestamp),
      };
      let msgs = state.messages || []; // 消息集合
      switch( model.name ) {
        case '温度':
          if(model.description !== '适中'){
            msgs.push(msg) // 追加数据
          }
          break;
        case '湿度':
          if(model.description !== '适中'){
            msgs.push(msg) // 追加数据
          }
          break;
        case '状态':
          if(model.value === '警报'){
            msgs.push(msg) // 追加数据
          }
          break;
        default:
          ;
      }
      return {
        ...state,
        messages: msgs,
      };
    },
    saveProducts(state, payload) {
      // const productList = payload.payload.productList;
      // console.log(payload,'payload')

      // 设备列表
      const ProductCategory = payload.payload.productList;
      const ProductList = payload.payload.product;
      let equNum = 0;   //设备总数
      let equItmeNum: [] = []; //设备数量列表
      let equState: [] = []
      let onLine = 0; //设备在线数量
      let offLine = 0;  //设备离线数量
      let wdSum = 0;  //温度总和
      let sdSum = 0;  //湿度总和

      let wsdItemdata = 0  //温湿度设备数量

      let tempMax = 0;
      let tempMin = 999;
      let tempNew = 0;
      let tempAver = "";

      let humMax = 0;
      let humMin = 999;
      let humNew = 0;
      let humAver = "";

      // 初始时间
      let humTime = 0
      let tempTime = 0
      // 单位获取
      let humUnit = ""
      let tempUnit = ""
      // 获取设备总和数量
      ProductList.map((value, key, arr) => {
        // 获取设备总数
        if (value.number == 'serialport' || value.number == 'onvifcamera' || value.number == 'fbee:0402:28' || value.number == 'fbee:0202:01'
          || value.number == 'fbee:0163:01' || value.number == 'fbee:0210:01'
        ) {
          return false
        }


        equNum += value.devices.length



        // 设备数量列表统计
        const equItem = { x: value.name, y: value.devices.length };
        console.log(value.number.substring(value.number.length - 2), 'valueNumber')
        // if(value.number !== 'fbee:0051:00' && value.number !== 'fbee:0106:00' && value.number !== 'fbee:0302:00' && value.number !== 'fbee:000a:00'){
        //   equItmeNum.push(equItem)
        // }
        if (value.number.substring(value.number.length - 2) !== '00') {
          equItmeNum.push(equItem)
        }

        // 设备状态
        let isOnline = 0;
        let isOffline = 0;
        value.devices.map((val, idx) => {
          if (val.isOnline) {
            isOnline++;
          } else {
            isOffline++;
          }
        })

        if (value.number.substring(value.number.length - 2) !== '00') {
          equState.push({ State: value.name, 离线: isOffline, 在线: isOnline, })
        }
        // if(value.number !== 'fbee:0051:00' && value.number !== 'fbee:000a:00'){
        //   equState.push({ State: value.name, 离线: isOffline, 在线: isOnline, })
        // }


        // 设备在线离线状态
        onLine += isOnline
        offLine += isOffline

        if (value.number === "fbee:0302:01") {
          // 获取设备数量
          wsdItemdata = value.devices.length

          // 获取设备列表
          const wsd = value.devices;

          wsd.map((wsdVal) => {
            // 循环温湿度内部项
            wsdVal.data.map((wsdItem) => {

              // const equtime = wsdItem.timeStamp
              const tempTimeNew = wsdItem.timestamp
              if (wsdItem.key === "Temperature") {
                // 计算总和
                // console.log(wsdItem, 'wsditem')
                wdSum += wsdItem.value * 1
                // 获取最大最小值
                tempMin = tempMin > wsdItem.value ? wsdItem.value : tempMin
                tempMax = tempMax > wsdItem.value ? tempMax : wsdItem.value
                // 最新时间温度值
                if (tempTimeNew > tempTime) {
                  tempNew = wsdItem.value
                  tempTime = tempTimeNew
                }
                // 获取单位
                tempUnit = wsdItem.unit
              }

              const humTimeNew = wsdItem.timestamp
              if (wsdItem.key === "Humidity") {

                // 计算总和
                sdSum += wsdItem.value * 1
                // 获取最大最小值
                humMax = humMax > wsdItem.value ? humMax : wsdItem.value
                humMin = humMin > wsdItem.value ? wsdItem.value : humMin

                // 最新时间温度值
                if (humTimeNew > humTime) {
                  humNew = wsdItem.value
                  humTime = humTimeNew
                }
                // 获取单位
                humUnit = wsdItem.unit
              }
            })
          })
        }


        // 平均温度
        tempAver = (wdSum / wsdItemdata).toFixed(2)

        // 平均湿度
        humAver = (sdSum / wsdItemdata).toFixed(2)

      })


      // console.log(tempNew, '最新温度')
      // console.log(humNew, '最新湿度')
      // console.log(tempMax, '最大温度')
      // console.log(tempMin, '最小温度')
      // console.log(humMax, '最大湿度')
      // console.log(humMin, '最小湿度')
      // console.log(wdSum, '温度总和')
      // console.log(sdSum, '湿度总和')
      // console.log(tempAver, '温度平均')
      // console.log(humAver, '湿度总和')
      // console.log(wsdItemdata, '温度湿度数量总和')


      // console.log(onLine, '所有设备在线')
      // console.log(offLine, '所有设备离线')
      // console.log(equState, '设备状态')
      // console.log(equNum, '设备总数')
      // console.log(equItmeNum, '每个设备数')



      // console.log('所有设备分类', ProductCategory)
      // console.log('所有设备', ProductList)

      return {
        ...state,
        // ...payload,
        equNum: equNum,
        equItem: equItmeNum,
        equState: equState,
        quaOnlineNum: onLine,
        quaOfflineNum: offLine,
        tempMin: tempMin,
        tempAver: tempAver,
        tempMax: tempMax,
        humMin: humMin,
        humAver: humAver,
        humMax: humMax,
        tempNew: tempNew,
        humNew: humNew,
        humUnit: humUnit,
        tempUnit: tempUnit
      };
    },
    clear() {
      return initState;
    },
  },

  subscriptions: {
    setup({ dispatch, history }): void {
      emitter.on('message', function (payload) {
        /**
         * deviceId: "75bae534-a2ff-4355-97cf-06e7acbacc57"
         * id: "f9f71b12-134e-4b18-ba33-335620ea6bc5"
         */
        if(payload.event === "dataEntityUpdated"){
          if(payload.model){
            if (dispatch) {
              dispatch({
                type: 'updateMessages',
                payload,
              });
            }
            if(payload.model.device.name !== '智能插座'){
              console.log('message=========', payload)
            }
            if(payload.model.name === '湿度'){
              if(payload.model.description !=='适中'){
                console.log(`湿度 ${payload.model.description}`)
              }else{
                console.log(`湿度适中`)
              }
              //console.log('message::::::::', payload)
            }
            if(payload.model.name === '温度'){
              if(payload.model.description !=='适中'){
                console.log(`温度 ${payload.model.description}`)
              }else{
                console.log(`温度适中`)
              }
              //console.log('message::::::::', payload)
            }
          }

        }

      })
    },
  },
};

export default Model;
