import { Card, Col, Row, Statistic, Tree, Modal } from 'antd';
import { FormattedMessage, formatMessage, } from 'umi';
import React, { Component } from 'react';
import { PoweroffOutlined } from '@ant-design/icons';
import { Dispatch, Action } from 'redux';
import { connect } from 'dva';
import { StateType } from '../model';
import style from '../style.less'
import request from '@/utils/request';

const { confirm } = Modal;

interface AllClassListProps {
  dashboardAndmonitor: StateType;
  dispatch: Dispatch<
  Action<
    | 'dashboardAndmonitor/getTemList'
    | 'dashboardAndmonitor/getLuxList'
    | 'dashboardAndmonitor/execScene'
    | 'dashboardAndmonitor/powerOn'
    | 'dashboardAndmonitor/powerOff'
  >
>;
  loading: boolean;
}

interface AllClassListState {
    temAry:any,
    luxAry:any,
}

class AllClassList extends Component<AllClassListProps,AllClassListState> {
 
  state:AllClassListState = {
    temAry:[],
    luxAry:[],
  }

  componentDidMount() {
    const { dispatch } = this.props;
    
     dispatch({
       type: 'dashboardAndmonitor/getTemList',
      callback: (response: any) => {
        if(response){
          this.setState({temAry:response.devices},()=>{this.getLuxList()})
        }
      }
     })
  }

  //获取光照列表
  getLuxList = () => {
     const { dispatch } = this.props;
     dispatch({
       type: 'dashboardAndmonitor/getLuxList',
      callback: (response: any) => {
        if(response){
          this.setState({luxAry:response.devices})
        }
      }
     })
  }

  //单个教室全部开
  showClassOper = (classData:any) => {
    let _this = this;
    confirm({
      title: '批量全开: 开灯、开关、插座',
      cancelText:'取消',
      okText:'确认',  
      onOk() {
        _this.showClassOneOn(classData)
        console.log('OK');
      },
    });
  }

  //单个教室开
  showClassOneOn = (data:any) => {

    
  request.post("/IoTCenter/api/v1/node/powerOn",{
  method: 'POST',
  headers: {
    'Authorization' : 'Bearer ' + localStorage.getItem('accessToken') 
  },
  data: '"'+ data.number +'"',
  }).then(function (response) {
             
            }).catch(function (error) {
                
            });


    // const { dispatch } = this.props;
   
    // dispatch({
    //   type: 'dashboardAndmonitor/powerOn',
    //   payload:'"'+ data.number +'"'
    // });
  }

    //单个教室全部关
    hideClassOper = (classData:any) => {
      let _this = this;
      confirm({
        title: '批量全关: 关灯、开关、插座',
        cancelText:'取消',
        okText:'确认',  
        onOk() {
          _this.showClassOneOff(classData)
          console.log('OK');
        },
      });
    }

    //单个教室关
    showClassOneOff = (data:any) => {
      request.post("/IoTCenter/api/v1/node/powerOff",{
        method: 'POST',
        headers: {
          'Authorization' : 'Bearer ' + localStorage.getItem('accessToken') 
        },
        data: '"'+ data.number +'"',
        }).then(function (response) {
                   
                  }).catch(function (error) {
                      
                  });

      // const { dispatch } = this.props;
     
      // dispatch({
      //   type: 'dashboardAndmonitor/powerOff',
      //   payload:'"'+ data.number +'"'
      // });
    }

  //获取教师列表
  getClassList = () => {
    let dom = [];
    if(this.props.classList.length > 0){
      
      this.props.classList.map((item:any)=>{
          dom.push(
            <Col className={style.classItem} span={6}>
            <Card  bordered={true}>
              <div className={style.classItemTitle}>
                <p style={{paddingTop:"1rem",paddingLeft:'8%',fontSize:'1rem',color:'#fff',fontWeight:'bold'}}>{item.title}</p>
                <p style={{paddingLeft:'8%',color:"#fff",fontSize:'0.8rem'}}>设备数量: {item.count}</p>
              </div>
              <div className={style.classItemContent}>
                {this.getTemClassInfo(item)}
              </div>
              <div className={style.classItemButton}>
                  <div className={style.itemOperStyle} onClick={()=>{this.showClassOper(item)}}>
                  <PoweroffOutlined style={{color:'#00DB00',fontSize:'1.5rem',cursor:'pointer'}}/>
                 <span style={{color:"#999",marginTop:'0.2rem',fontSize:'0.8rem'}}>批量开</span>
                 </div>
                  <div  className={style.itemOperStyle} onClick={()=>{this.hideClassOper(item)}}>
                 <PoweroffOutlined style={{color:'#FF0000',fontSize:'1.5rem',cursor:'pointer'}}/>
                 <span style={{color:"#999",marginTop:'0.2rem',fontSize:'0.8rem'}}>批量关</span>
                  </div>
              </div>
            </Card>
            </Col>
          
          )
      })
    }else {
      dom.push(
        <div>
        暂无数据
        </div>
      )
    }
   
    return dom
  }

   //获取对应教室温度
   getTemClassInfo = (classData:any) => {
      let dom:any = [];
      this.state.temAry.map((item:any)=>{
        if(item.nodeId == classData.key){

          item.data.map((item1:any)=>{
            if(item1.key == "Warning"){
              dom.push(
                <p className={style.tempStyle}>{`${item.displayName}(${item1.name}) : ${item1.value}`}</p>
                )
            }
          })
          
          item.data.map((item1:any)=>{
            if(item1.key == "Temperature"){
              dom.push(
                <p className={style.tempStyle}>{`${item1.name}: ${item1.value}${item1.unit}`}</p>
                )
            }        
          })

          item.data.map((item1:any)=>{
            if(item1.key == "Humidity"){
              dom.push(
                <p className={style.tempStyle}>{`${item1.name}: ${item1.value}${item1.unit}`}</p>
                )
            }
          })
     
        }
      
      })

      this.state.luxAry.map((item:any)=>{
        if(item.nodeId == classData.key){

          item.data.map((item1:any)=>{
            if(item1.key == "Warning"){
              dom.push(
                <p className={style.tempStyle}>{`${item.displayName}(${item1.name}): ${item1.value}`}</p>
                )
            }
          })

          item.data.map((item1:any)=>{
            
            if(item1.key == "Light"){
              dom.push(
                <p className={style.tempStyle}>{`${item1.name}: ${item1.value}${item1.unit}`}</p>
                )
            }

          })

      
     
        }
      
      })

      
      return dom
  }

  //所有教室全部开
  showAllOper = () => {
    let _this = this
      confirm({
        title: '批量全开: 开灯、开关、插座',
        cancelText:'取消',
        okText:'确认',  
        onOk() {
          _this.showDisOperOn()

          console.log('OK');
        },
      });
    }
  //所有教室开
  showDisOperOn = () => {
    // const { dispatch } = this.props;
    this.props.classList.map((item:any)=>{
      request.post("/IoTCenter/api/v1/node/powerOn",{
        method: 'POST',
        headers: {
          'Authorization' : 'Bearer ' + localStorage.getItem('accessToken') 
        },
        data: '"'+ item.number +'"',
        }).then(function (response) {
                   
                  }).catch(function (error) {
                      
                  });
      // dispatch({
      //   type: 'dashboardAndmonitor/powerOn',
      //   payload: '"'+ item.number +'"'
      // });
    })
  
  }  

  //所有教室全部关
  hideAllOper = () => {
    let _this = this
    confirm({
      title: '批量全关: 关灯、开关、插座',
      cancelText:'取消',
      okText:'确认',  
      onOk() {
        _this.showDisOperOff()
        console.log('OK');
      },
    });
  }

    //所有教室关
    showDisOperOff = () => {
      // const { dispatch } = this.props;
      this.props.classList.map((item:any)=>{
        request.post("/IoTCenter/api/v1/node/powerOff",{
          method: 'POST',
          headers: {
            'Authorization' : 'Bearer ' + localStorage.getItem('accessToken') 
          },
          data: '"'+ item.number +'"',
          }).then(function (response) {
                     
                    }).catch(function (error) {
                        
                    });
        // dispatch({
        //   type: 'dashboardAndmonitor/powerOff',
        //   payload: '"'+ item.number +'"'
        // });
      })
    } 

  render() {
    
    console.log(this.props.classList)
    return (
        <div style={{width:'100%',minHeight:'40rem'}}>  
        <Card bordered={true}>
          <Row className={style.operSpanStyle}>
           <Statistic title="" value='快捷操作'  valueStyle={{ fontSize:'1rem'}}/>
          </Row>
          <Row className={style.operButtonStyle}>
            <div className={style.allOperStyle} onClick={()=>{this.showAllOper()}}>
            <PoweroffOutlined style={{color:'#00DB00',fontSize:'2rem',cursor:'pointer'}}/>
            <Statistic title="" value='批量全部开'  valueStyle={{ fontSize:'0.7rem',marginTop:'0.2rem'}}/>
         
            </div>
            <div  className={style.allOperStyle} onClick={()=>{this.hideAllOper()}}>
            <PoweroffOutlined style={{color:'#FF0000',fontSize:'2rem',cursor:'pointer'}}/>
            <Statistic title="" value='批量全部关'  valueStyle={{ fontSize:'0.7rem',marginTop:'0.2rem'}}/>
          
            </div>
          </Row>
          </Card>
          <Row className={style.classDiv} gutter={16}>
            {this.getClassList()}
          </Row>
        </div>
    );
  }
}

export default connect(
  ({
    dashboardAndmonitor,
    loading,
  }: {
    dashboardAndmonitor: StateType;
    loading: {
      models: { [key: string]: boolean };
    };
  }) => ({
    dashboardAndmonitor,
    loading: loading.models.dashboardAndmonitor,
  }),
)(AllClassList);
