import { Card, Col, Row, Statistic, Tree } from 'antd';
import { MicroApp } from 'umi';
import React, { Component } from 'react';
import AllClassList from './components/AllClassList'
import { Dispatch, Action } from 'redux';
import { connect } from 'dva';
import { StateType } from './model';
import style from './style.less';
import ClassInfoCom from './components/ClassInfoCom'

interface MonitorProps {
  dashboardAndmonitor: StateType;
  dispatch: Dispatch<
    Action<
      | 'dashboardAndmonitor/getClassList'
      | 'dashboardAndmonitor/getClassInfo'
    >
  >;
  loading: boolean;
}

interface MonitorState {
  treeAry: any,
  allNode: any,
  rightClass: any,
  pageType: any,
  classInfo: any,
  selectClassId: any, //已选班级ID
}

class Monitor extends Component<MonitorProps, MonitorState> {

  state: MonitorState = {
    treeAry: [],
    allNode: [],
    rightClass: [],
    pageType: true,
    classInfo: {},
    selectClassId: "",
  }

  componentDidMount() {
    const { dispatch } = this.props;

    dispatch({
      type: 'dashboardAndmonitor/getClassList',
      callback: (response: any) => {

        if (response.length > 0) {
          let newTreeAry: any = [];
          let allClassInfo: any = [];
          response.map((item: any) => {
            if (item.category !== null) {
              if (newTreeAry.length === 0) {

                newTreeAry.push({
                  key: item.category.id,
                  title: item.category.name,
                  level: '1',
                  children: [],
                });


              } else if (newTreeAry.length > 0) {

                let isPut = true
                newTreeAry.map((item2: any) => {
                  if (item2.key == item.category.id) {
                    isPut = false
                  }
                })

                if (isPut === true) {
                  newTreeAry.push({
                    key: item.category.id,
                    title: item.category.name,
                    level: '1',
                    children: [],
                  });
                }
              }


              allClassInfo.push({
                key: item.id,
                title: item.name,
                count: item.count,
                level: '1',
                number: item.number
              })
            }

          })


          newTreeAry.map((item: any) => {
            response.map((item1: any) => {
              if (item1.category !== null) {
                if (item.key == item1.category.id) {
                  item.children.push({
                    key: item1.id,
                    title: item1.name,
                    count: item1.count,
                    level: '2',
                    number: item1.number
                  })
                }
              }
            })

          })

          response.map((item1: any) => {
            if (item1.category == null) {
              newTreeAry.push({
                key: item1.id,
                title: item1.name,
                count: item1.count,
                level: '2',
                number: item1.number
              })
            }
          })

          let allAry = [{ key: '0', title: '智慧教室', level: '0', children: newTreeAry }]
          this.state.allNode = allClassInfo;
          this.setState({ treeAry: allAry, rightClass: this.state.allNode })

          console.log(newTreeAry, 'ary')
        } else {
          let allAry = [{ key: '0', title: '智慧教室', level: '0', children: [] }]
          this.setState({ treeAry: allAry })

        }
      },
    });
  }

  //点击树节点
  onTreeSelect = (selectedKeys: any, e: any) => {

    console.log(e)
    if (e.selectedNodes.length > 0) {
      let level: any = e.selectedNodes[0].level;
      if (level == '0') {
        this.setState({ rightClass: this.state.allNode, pageType: true })
      } else if (level == '1') {
        this.setState({ rightClass: e.selectedNodes[0].children, pageType: true })
      } else {
        this.getClassCareInfo(e.selectedNodes[0].number)
      }
    }

  }

  //获取班级详细信息
  getClassCareInfo = (classNumber: any) => {
    // this.setState({pageType:false,selectClassId:classNumber})
    const { dispatch } = this.props;

    dispatch({
      type: 'dashboardAndmonitor/getClassInfo',
      payload: {
        number: classNumber
      },
      callback: (response: any) => {
        if (response) {
          this.setState({ pageType: false, selectClassId: classNumber })
        }
      }
    })
  }

  render() {

    return (
      <div style={{ width: '100%', minHeight: '40rem' }}>

        {this.state.treeAry.length > 0 ?
          <Row gutter={[16, 0]}>
            <Col span={4} style={{ minHeight: '40rem', background: "#fff" }}>

              <Tree
                showLine={true}
                defaultExpandedKeys={['0']}
                defaultSelectedKeys={['0']}
                treeData={this.state.treeAry}
                className={style.treeStyle}
                onSelect={this.onTreeSelect}
              />

            </Col>
            <Col span={20}>

              {this.state.pageType === true ?
                <AllClassList classList={this.state.rightClass} />
                :
                // <MicroApp name="classTwo" />
                // <MicroApp name="classInfo" id={this.state.selectClassId}/>
                // <MicroApp name="helloWord" id={this.state.selectClassId}/>
                <ClassInfoCom />
              }

            </Col>
          </Row> : null}

      </div>
    );
  }
}

export default connect(
  ({
    dashboardAndmonitor,
    loading,
  }: {
    dashboardAndmonitor: StateType;
    loading: {
      models: { [key: string]: boolean };
    };
  }) => ({
    dashboardAndmonitor,
    loading: loading.models.dashboardAndmonitor,
  }),
)(Monitor);
