import React, { useRef, useState, useEffect, Component } from 'react';
import ProTable, { ProColumns } from '@ant-design/pro-table';
import { FormInstance } from 'antd/lib/form';
import { Dispatch, Action } from 'redux';
import { connect } from 'dva';
import { ModalState } from '../model';
import request from '@/utils/request';
import { Table, Card, Form, Col, Row, Button, Select, Input } from 'antd';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import styles from '../style.less';
import { getPageQuery } from '@/utils/utils';
const FormItem = Form.Item;


interface AllProductState {
  listAry: any;
  selectProductId: any;
  isOnline: any;
}

class AllProductInfo extends Component<AllProductState>{

  state: AllProductState = {
    listAry: [],
    selectProductId: "",
    isOnline: "",
  }

  columns = [
    {
      title: '设备种类',
      dataIndex: 'name',

    },
    {
      title: '设备名称',
      dataIndex: 'displayName',
    },

    {
      title: '在线状态',
      dataIndex: 'isOnline',
      render: (text: any) => [
        <span>{text === true ? '在线' : '离线'}</span>
      ],
    },
    {
      title: '编号',
      dataIndex: 'number',
    },
  ];

  componentDidMount() {
    let _this = this
    this.getAllList(_this)
  }


  getAllList = (_this: any) => {

    const queryParams = getPageQuery();
    let schoolID = ""
    queryParams.schoolId ? schoolID = `&query.organNumber=${queryParams.schoolId}` : schoolID = "";
    request.get(`/IoTCenter/admin/Device/Index?pageIndex=1&pageSize=9999&query.productId=${this.state.selectProductId}&query.isOnline=${this.state.isOnline}${schoolID}`, {
      method: 'GET',
      headers: {
        'Authorization': 'Bearer ' + localStorage.getItem('accessToken')
      },
    }).then(function (response) {

      _this.setState({ listAry: response.model.list })
    }).catch(function (error) {

    });


  }



  //查询
  handleSearch = (values: any) => {
    // e.preventDefault();

    this.state.selectProductId = values.proCategroy == "0" ? "" : values.proCategroy;
    this.state.isOnline = values.status === 1 ? "" : values.status === 2 ? true : false
    let _this = this
    this.getAllList(_this)

  };

  renderSimpleForm() {

    return (
      <Form onFinish={(values) => { this.handleSearch(values) }} layout="inline">
        <Row gutter={{ md: 8, lg: 24, xl: 48 }} style={{ width: "100%", marginLeft: '-8px' }}>
          <Col md={6} sm={6}>
            <FormItem label="设备种类" name="proCategroy" initialValue={this.props.listAry[0].id}>
              <Select
                style={{ width: '100%' }}
                onChange={(value) => { }}
              >
                {this.props.listAry.map((item: any) => (
                  <Select.Option value={item.id} key={item.id} >{item.name}</Select.Option>
                ))}
              </Select>
            </FormItem>
          </Col>
          <Col md={4} sm={6}>
            <FormItem label="在线状态" name="status" initialValue={1}>
              <Select
                style={{ width: '100%' }}
                onChange={(value: any) => { }}
              >
                <Select.Option value={1} key={1} >{'全部'}</Select.Option>
                <Select.Option value={2} key={2}>{'是'}</Select.Option>
                <Select.Option value={3} key={3} >{'否'}</Select.Option>
              </Select>
            </FormItem>
          </Col>
          <Col md={4} sm={6}>
            <span className={styles.submitButtons}>
              <Button type="primary" htmlType="submit">
                查询
              </Button>
            </span>
          </Col>
          {/* <Col md={4} sm={6}>
            <FormItem label="班级">
              {getFieldDecorator('class', { initialValue: this.state.selectClassId })(
                <Select
                  style={{ width: '100%' }}
                  showSearch={true}
                  onChange={(value: any) => { this.state.selectClassId = value; this.getStudentList(this.state.selectClassId, this.state.xm) }}
                >
                  {this.state.classList.map(item => (
                    <Select.Option value={item.class_id} key={item.class_id} >{item.class_name}</Select.Option>
                  ))}
                </Select>)}
            </FormItem>
          </Col>
          <Col md={6} sm={6}>
            <FormItem label="学生姓名">
              {getFieldDecorator('studentName')(
                <Input placeholder="请输入学生姓名" allowClear={true} maxLength={20}
                  onChange={(e) => { this.state.xm = e.target.value }}
                />,
              )}
            </FormItem>
          </Col>
          <Col md={4} sm={6}>
            <span className={styles.submitButtons}>
              <Button type="primary" htmlType="submit">
                查询
              </Button>
            </span>
          </Col> */}
        </Row>

      </Form>
    );
  }





  // useEffect(() => {
  //   const { dispatch } = props;
  //   
  //   dispatch({
  //     type: 'dashboardAndworkplace/getProductAllInfo',
  //     payload:{...allParams}
  //   })
  //   }, []);

  render() {
    const pagination = {
      showSizeChanger: true,
      showQuickJumper: true,
      pageSize: 20,
    }
    return (
      <Card bordered={false}>
        <div className={styles.tableListForm}>{this.renderSimpleForm()}</div>
        <Table columns={this.columns} dataSource={this.state.listAry} pagination={pagination} />
      </Card>
    )
  }
}

export default connect(
  ({
    dashboardAndworkplace,
    loading,
  }: {
    dashboardAndworkplace: ModalState;
    loading: {
      models: { [key: string]: boolean };
    };
  }) => ({
    dashboardAndworkplace,
    loading: loading.models.dashboardAndworkplace,
  }),
)(AllProductInfo);