import React, { useRef, useState, useEffect } from 'react';
import ProTable, { ProColumns } from '@ant-design/pro-table';
import { FormInstance } from 'antd/lib/form';
import { Dispatch, Action } from 'redux';
import { connect } from 'dva';
import { ModalState } from '../model';


const columns: ProColumns[] = [
  {
    title: '设备名称',
    dataIndex: 'name',
  },
  {
    title: '所属教室',
    dataIndex: 'className',
  },
  {
    title: '在线状态',
    hideInSearch: true,
    dataIndex: 'status',
    render: (text) => [<span>{text == true ? '在线' : '离线'}</span>],
  },
  {
    title: '光照度',
    dataIndex: 'lightInfo',
    hideInSearch: true,
  },
];

const LightTable = (props: any) => {

  useEffect(() => {

    const { dispatch } = props;

    dispatch({
      type: 'dashboardAndworkplace/getProductInfoLight',
    })


  }, []);

  const ref = useRef<FormInstance>();
  const [collapsed, setCollapsed] = useState(false);
  return (
    <ProTable
      columns={columns}
      request={(params = {}) =>
        Promise.resolve({
          data: props.dashboardAndworkplace.productLight?.filter((item) => {

            if ((params.name === undefined || params.name == "") && (params.className === undefined || params.className == "")) {
              return true;
            }

            if (item.name.includes(params.name)) {
              if (params.className === undefined || params.className == "") {
                return true
              } else if (item.className.includes(params.className)) {
                return true
              }

            } else if (item.className.includes(params.className)) {
              if (params.name === undefined || params.name == "") {
                return true
              } else if (item.name.includes(params.name)) {
                return true
              }
            }

          }),
          success: true,
        })
      }
      rowKey="key"
      pagination={{
        showSizeChanger: true,
      }}
      search={{
        collapsed
      }}
      formRef={ref}
      options={false}
      dateFormatter="string"
      headerTitle="光强检测器"
    />
  );
};

export default connect(
  ({
    dashboardAndworkplace,
    loading,
  }: {
    dashboardAndworkplace: ModalState;
    loading: {
      models: { [key: string]: boolean };
    };
  }) => ({
    dashboardAndworkplace,
    loading: loading.models.dashboardAndworkplace,
  }),
)(LightTable);