import React, { useRef, useState, useEffect } from 'react';
import ProTable, { ProColumns } from '@ant-design/pro-table';
import { FormInstance } from 'antd/lib/form';
import { Dispatch, Action } from 'redux';
import { connect } from 'dva';
import { ModalState } from '../model';
import { PoweroffOutlined } from '@ant-design/icons';




const SocketTable = (props: any) => {

  const columns: ProColumns[] = [
    {
      title: '设备名称',
      dataIndex: 'name',
    },
    {
      title: '所属教室',
      dataIndex: 'className',
    },
    {
      title: '设备状态',
      dataIndex: 'severStatus',
      hideInSearch: true,
    },
    {
      title: '在线状态',
      hideInSearch: true,
      dataIndex: 'status',
      render: (text) => [<span>{text === true ? '在线' : '离线'}</span>],
    },
    {
      title: '操作',
      hideInSearch: true,
      dataIndex: 'severStatus',
      render: (text, record) => {
        if (record.status === true) {
          return <PoweroffOutlined style={{ color: text === '开' ? '#00DB00' : '#FF0000', fontSize: '1.2rem', cursor: 'pointer' }}
            onClick={() => onOutOper(record)} title={text == '开' ? '关' : '开'}
          />
        } else {
          return '--'
        }
      }
    },
  ];


  const onOutOper = (data: any) => {

    const { dispatch } = props;

    dispatch({
      type: 'dashboardAndworkplace/exec',
      payload: { connectionId: window['connectionId'], number: data.number, method: data.severStatus == '开' ? '/Switch/Off' : '/Switch/On' }
    });
  }

  useEffect(() => {

    const { dispatch } = props;

    dispatch({
      type: 'dashboardAndworkplace/getProductInfoSocket',
    })

  }, []);

  const ref = useRef<FormInstance>();
  const [collapsed, setCollapsed] = useState(false);
  return (
    <ProTable
      columns={columns}
      request={(params = {}) =>
        Promise.resolve({
          data: props.dashboardAndworkplace.productSocket?.filter((item) => {

            if ((params.name === undefined || params.name == "") && (params.className === undefined || params.className == "")) {
              return true;
            }

            if (item.name.includes(params.name)) {
              if (params.className === undefined || params.className == "") {
                return true
              } else if (item.className.includes(params.className)) {
                return true
              }

            } else if (item.className.includes(params.className)) {
              if (params.name === undefined || params.name == "") {
                return true
              } else if (item.name.includes(params.name)) {
                return true
              }
            }

          }),
          success: true,
        })
      }
      rowKey="key"
      pagination={{
        showSizeChanger: true,
      }}
      search={{
        collapsed,
        onCollapse: setCollapsed,
      }}
      formRef={ref}
      options={false}
      dateFormatter="string"
      headerTitle="插座"
    />
  );
};

export default connect(
  ({
    dashboardAndworkplace,
    loading,
  }: {
    dashboardAndworkplace: ModalState;
    loading: {
      models: { [key: string]: boolean };
    };
  }) => ({
    dashboardAndworkplace,
    loading: loading.models.dashboardAndworkplace,
  }),
)(SocketTable);