import { Card, Col, Row, Statistic, Tree, Menu } from 'antd';
import { FormattedMessage, formatMessage, } from 'umi';
import React, { Component } from 'react';
import { Dispatch, Action } from 'redux';
import { connect } from 'dva';
import { ModalState } from './model';
import style from './style.less';
import GateWayTable from "./components/GateWayTable"
import OneSwitchTable from "./components/OneSwitchTable"
import ThreeSwitchTable from "./components/ThreeSwitchTable"
import SensorBodyTable from "./components/SensorBodyTable"
import LightTable from './components/LightTable';
import SocketTable from './components/SocketTable';
import SuperSocketTable from './components/SuperSocketTable';
import TemperTable from './components/TemperTable';
import LockTable from "./components/LockTable"
import AllProductInfo from "./components/AllProductInfo"

interface WorkPlaceProps {
  dashboardAndworkplace: ModalState;
  dispatch: Dispatch<
    Action<
      | 'dashboardAndworkplace/getProductList'
    >
  >;
  loading: boolean;
}

interface WorkPlace {
  listAry: any;
  selectPro: any;
  rand: number;
}

class WorkPlace extends Component<WorkPlaceProps, WorkPlace> {

  state: WorkPlace = {
    listAry: [],
    selectPro: '',
    rand: 0
  }

  componentDidMount() {
    const { dispatch } = this.props;
    dispatch({
      type: 'dashboardAndworkplace/getProductList',
      callback: (response: any) => {
        if (response) {
          let ary: any = [];
          let allCount = 0;

          response.map((item: any) => {
            if (item.number == 'fbee:gateway' || item.number == 'fbee:0002:01' || item.number == 'fbee:0002:03' || item.number == 'fbee:0402:0d'
              || item.number == 'fbee:0106:01' || item.number == 'fbee:0009:01' || item.number == 'fbee:0051:01' || item.number == 'fbee:0302:01' || item.number == 'fbee:000a:01'
            ) {
              allCount += item.count
              ary.push(
                item
              )
            }

          })

          ary.unshift({
            count: allCount,
            id: '0',
            name: '全部设备',
            number: 'fbee:all'
          })

          this.setState({ listAry: ary, selectPro: ary[0].number })
        }
      }
    })
  }


  //左侧设备列表渲染
  renderMenuData = () => {
    let dom: any = [];

    this.state.listAry.map((item: any) => {
      dom.push(
        <Menu.Item key={item.number}>{item.name}{`( ${item.count} )`}</Menu.Item>
      )
    })

    return dom;
  }

  //获取右侧表格
  getProTables = () => {


    switch (this.state.selectPro) {
      case 'fbee:all':
        return <AllProductInfo listAry={this.state.listAry} />;

      case 'fbee:gateway':
        return <GateWayTable />;

      case 'fbee:0002:01':
        return <OneSwitchTable />;

      case 'fbee:0002:03':
        return <ThreeSwitchTable />;

      case 'fbee:0402:0d':
        return <SensorBodyTable />;

      case 'fbee:0106:01':
        return <LightTable rand={this.state.rand} />;

      case 'fbee:0009:01':
        return <SocketTable />;

      case 'fbee:0051:01':
        return <SuperSocketTable />;

      case 'fbee:0302:01':
        return <TemperTable />;

      case 'fbee:000a:01':
        return <LockTable rand={this.state.rand} />;

      default:
        return ''

    }


  }

  //点击左侧菜单回调
  onMenuClick = (item: any, key: any, keyPath: any, domEvent: any) => {

    this.setState({ selectPro: item.key, rand: Math.random() })
  }

  render() {

    console.log(this.state)
    return (
      <div style={{ width: '100%', minHeight: '40rem' }}>

        <Row gutter={[16, 0]}>
          <Col span={4} className={style.leftMenu}>
            <Card bordered={false} style={{ minHeight: '40rem' }}>
              <Menu
                selectedKeys={[this.state.selectPro]}
                style={{ border: "none", fontSize: '0.875rem' }}
                onSelect={this.onMenuClick}
              >
                {this.renderMenuData()}
              </Menu>
            </Card>

          </Col>
          <Col span={20}>
            {this.getProTables()}


          </Col>
        </Row>

      </div>
    );
  }
}

export default connect(
  ({
    dashboardAndworkplace,
    loading,
  }: {
    dashboardAndworkplace: ModalState;
    loading: {
      models: { [key: string]: boolean };
    };
  }) => ({
    dashboardAndworkplace,
    loading: loading.models.dashboardAndworkplace,
  }),
)(WorkPlace);
