import React, { useState, useEffect } from 'react';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { Card, Typography, Alert, Avatar, Button, Row, Col, Select, Menu } from 'antd';
import styles from '../Welcome.less';
import { connect, Dispatch, MicroApp } from 'umi';
import SubMenu from 'antd/lib/menu/SubMenu';
import { MailOutlined, PieChartOutlined } from '@ant-design/icons';
//import { ConnectState } from '@/models/connect';
// import { StateType } from './model';
interface DemoProps {
  status: string;
  devices: [];
  dispatch: Dispatch;
  loading: boolean;
}

const { Option } = Select;

const Demo = (props: DemoProps) => {
  const [valueMenu, setValueMenu] = useState('1');
  const { dispatch, } = props;
  useEffect(() => {
    if (dispatch) {
      dispatch({
        type: 'demo/fetch',
        payload: 'fbee:0002:01'
      });
    }
  }, []);

  const CodePreview: React.FC<{}> = ({ children }) => (
    <pre className={styles.pre}>
      <code>
        <Typography.Text copyable>{children}</Typography.Text>
      </code>
    </pre>
  );

  const handleExecApi = () => {
    if (dispatch) {
      dispatch({
        type: 'demo/exec',
        payload: {connectionId: window['connectionId'], number:'1165f469-00124B001D3EF7E9', method:props.status === 'on' ? '/Switch/Off' : '/Switch/On'}
      });
    }
  };

  const handleClick = (menu:any) => {
    setValueMenu(menu.key)
  };

  return (
  <PageHeaderWrapper>
    <Row>
      <Col span={6}>
        <Menu
          onClick={handleClick}
          style={{ width: 256 }}
          defaultSelectedKeys={['1']}
          defaultOpenKeys={['sub1']}
          mode="inline"
        >
            <Menu.Item key="1" icon={<PieChartOutlined />}>
              Option 1
            </Menu.Item>
            <Menu.Item key="2" icon={<PieChartOutlined />}>
              Option 3
            </Menu.Item>
        </Menu>
      </Col>
      <Col span={18}>
      <div style={{background:'#ccc',padding:30}}><MicroApp name="helloworld" id={valueMenu} /></div>
      </Col>
    </Row>




    <MicroApp name="s" /><MicroApp name="app1" />
    <Select defaultValue="lucy" style={{ width: 120 }}>
      <Option value="jack">Jack</Option>
      <Option value="lucy">Lucy</Option>
      <Option value="disabled" disabled>
        Disabled
      </Option>
      <Option value="Yiminghe">yiminghe</Option>
    </Select>

    <div className="site-card-border-less-wrapper" style={{ marginTop: 50 }}>
      <Card>
        <Alert
          message="基于Websocket协议 通过 @aspnet/signalr 数据通信"
          type="success"
          showIcon
          banner
          style={{
            margin: -12,
            marginBottom: 24,
          }}
        />

          <strong>安装npm组件</strong>
          <div style={{background: '#333'}}>
          <CodePreview> yarn add @aspnet/signalr</CodePreview>
          </div>
          <p>
  访问 一路开关（1165f469-00124B001D3EF7E9）
          <a target="_blank" rel="noopener noreferrer" href="http://iot.edusoa.com/#/routes/iot/device.html?number=1165f469-00124B001D3EF7E9">
          后台管理页面
          </a> 操控，当前页面同步相应状态</p>

        <strong>src/app.ts</strong>
        <div style={{background: '#333'}}>
          <CodePreview >
            {`import { HubConnectionBuilder } from "@aspnet/signalr";
import emitter from './utils/events';

const connection = new HubConnectionBuilder().withUrl('http://iot.edusoa.com/IoTCenter/hub?group=page').build();
let connectionId;

connection.on('Connected', function (id: string) {
  connectionId = id;
});

/**
 * 接收服务端消息
 */
connection.on("ServerToClient", (method: string, message: string, to: string, from: string) => {
  /**
     * 格式化事件字符串
     */
    var event = method.substr(0, 1).toLowerCase() + method.substr(1);
    /**
     * 触发自定义事件message
     * 监听方法：
     * emitter.on('message', function (text) {
     *   alert(text)
     * })
     */
    var model = JSON.parse(message);
    emitter.emit('message', {event: event, model: model, to: to, from: from});
});
connection.start(); // websocket 初始化`}
          </CodePreview>
        </div>
        <div className="site-card-border-less-wrapper" style={{ marginTop: 15 }}>
          <Card title={<><span>一路开关</span> <strong style={{float: 'right'}}>{props.status}</strong></>} bordered={true} style={{ width: '25%', minWidth: 320 }}>
            <Row>
              <Col span={8}><Avatar shape="square" style={{width:50, height:50}} src="./images/switch.svg" /></Col>
              <Col span={16}><Button type="primary" onClick={handleExecApi} shape="circle" style={{width:50, height:50}} icon={<img src={`../images/${props.status}.svg`} style={{ width:"80%", marginTop:-3}} />}/></Col>
            </Row>
          </Card>
        </div>
      </Card>
    </div>

    <div className="site-card-border-less-wrapper" style={{ marginTop: 50 }}>
      <Card>
        <Alert
          message="通过 EventEmitter （events） 定义自定义事件"
          type="success"
          showIcon
          banner
          style={{
            margin: -12,
            marginBottom: 24,
          }}
        />
        <strong>utils/events.ts</strong>
        <div style={{background: '#333'}}>
          <CodePreview >
            {`import { EventEmitter } from 'events';
export default new EventEmitter();`}
          </CodePreview>
        </div>
      </Card>
    </div>

    <div className="site-card-border-less-wrapper" style={{ marginTop: 50 }}>
      <Card>
        <Alert
          message="基于umi/dva subscriptions 订阅"
          type="success"
          showIcon
          banner
          style={{
            margin: -12,
            marginBottom: 24,
          }}
        />
          <strong>subscriptions</strong>
          <div style={{background: '#333'}}>
            <CodePreview >
              {`subscriptions: {
  setup({ dispatch, history }): void {
    emitter.on('message', function (payload) { // 自定义事件
      if(payload.event === "dataEntityUpdated"){
        if(payload.model && payload.model.id && payload.model.id === 'f9f71b12-134e-4b18-ba33-335620ea6bc5'){
          if (dispatch) {
            dispatch({
              type: 'update',
              payload
            });
          }
        }
      }
    })
  },
},`}
          </CodePreview>
        </div>
      </Card>
    </div>

    <div className="site-card-border-less-wrapper" style={{ marginTop: 50 }}>
    <Card>
    <Alert
        message="基于UMI 3.0通过react hooks / useEffect从API接口获取数据 (注：后续将尝试采用ahooks替代react hooks)"
        type="success"
        showIcon
        banner
        style={{
          margin: -12,
          marginBottom: 24,
        }}
      />
      <div style={{background: '#333'}}>
      <CodePreview >
        {`  const { dispatch, } = props;
  useEffect(() => {
    if (dispatch) {
      dispatch({
        type: 'demo/fetch',
        payload: 'fbee:0002:01'
      });
    }
  }, []);`}</CodePreview>
      </div>

      {props.devices.map((device: any) => (
        <div>
        <Card title={device.name} bordered={true} style={{ width: '25%', minWidth: 320 }}>
          <Row>
            <Col span={24}><Avatar shape="square" style={{width:50, height:50}} src={`./images/${device.icon}.svg`} /></Col>
            <Col span={24}><strong>{device.number}</strong></Col>
          </Row>
        </Card>
        </div>
      ))}
      </Card>
    </div>

  </PageHeaderWrapper>
  )
}
// 绑定 State 到 View
export default connect(
({ demo }: { demo: any }) => ({
  status: demo.status,
  devices: demo.devices,
}))(Demo);
