import { Subscription, Reducer, Effect } from 'umi';

// import { ConnectState } from './connect.d';
import emitter from '@/utils/events';
import { getProduct, execApi } from './service';

export interface StateType {
  status?: string;
  devices?: [];
}

export interface ModelType {
  namespace: string;
  state: ModelState;
  effects: {
    fetch: Effect;
    exec: Effect;
  };
  reducers: {
    save: Reducer<StateType>;
    update: Reducer<StateType>;
  };
  subscriptions: { setup: Subscription };
}

export interface ModelState {
  status: string;
  devices: [];
}

const Model: ModelType = {
  namespace: 'demo',
  state: {
    status: 'off',
    devices: [],
  },
  effects:{
    // 获取产品列表（通过Rest API）
    *fetch({ payload, callback }, { call, put }) {
      const response = yield call(getProduct, payload);
      yield put({
        type: 'save',
        payload: response.devices,
      });
    },
    *exec({ payload, callback }, { call, put }) {
      const response = yield call(execApi, payload);
    },
  },
  reducers: {
    save(state, { payload }) {
      return {
        ...state,
        devices: payload,
      };
    },
    update(state, action) {
      let val = '';
      switch( action.payload.model.value ) {
        case '开':
          val = 'on';
          break;
        case '关':
          val = 'off';
          break;
        default:
          '';
      }
      return {
        ...state,
        status: val,
      };
    },
  },
  subscriptions: {
    setup({ dispatch, history }): void {
      emitter.on('message', function (payload) {
        /**
         * deviceId: "75bae534-a2ff-4355-97cf-06e7acbacc57"
         * id: "f9f71b12-134e-4b18-ba33-335620ea6bc5"
         */
        if(payload.event === "dataEntityUpdated"){
          if(payload.model && payload.model.id && payload.model.id === 'f9f71b12-134e-4b18-ba33-335620ea6bc5'){
            if (dispatch) {
              dispatch({
                type: 'update',
                payload
              });
            }
            //console.log('message::::', payload)
          }

        }

      })
    },
  },
};

export default Model;
